@@ -215,7 +215,7 @@ class MigrationHandler(object):
 			if current_rev == 0 and snapshots:
 				# To generate snapshots use `pg_dump -F p --inserts` and delete the table db_version from the generation SQL
 				try:
-					snapshot_rev = max(rev for rev in snapshots.iterkeys() if rev <= target_rev)
+					snapshot_rev = max(rev for rev in snapshots.keys() if rev <= target_rev)
 				except ValueError:
 					pass # no snapshot for a rev <= target_rev
 				else:
